@@ -41,6 +41,22 @@ if (interactive()) {
     test_that("cXmap10", {
         check_ui_test(cXmap10())
     })
+
+    test_that("cXmap11", {
+        check_ui_test(cXmap11())
+    })
+
+    test_that("cXmap12", {
+        check_ui_test(cXmap12())
+    })
+
+    test_that("cXmap13", {
+        check_ui_test(cXmap13())
+    })
+
+    test_that("cXmap14", {
+        check_ui_test(cXmap14())
+    })
 } else {
     message("Non-interactive ui-map tests skipped")
 }
